<?php
namespace bwdvsix_VerticalSlideshow_namespace;

use bwdvsix_VerticalSlideshow_namespace\PageSettings\Page_Settings;
define( "bwdvsix_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "bwdvsix_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class Classbwdvsix_VerticalSlideshow {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdvsix_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdvsix_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdvsix_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdvsix_VerticalSlideshow_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdvsix-vertical-slideshow-widgets.php' );
	}

	public function bwdvsix_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdvsix_VerticalSlideshow_widgets());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdvsix-vertical-slideshow-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdvsix_VerticalSlideshow_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdvsix-VerticalSlideshow-category',
			[
				'title' => esc_html__( 'Vertical Split Slideshow', 'bwdvsix-slideshow-vertical' ),
				'icon' => 'eicon-person',
			]
		);
	}

	//css-js-link-here
	public function bwdvsix_all_assets_for_the_public(){
		wp_enqueue_script( 'bwdvsix-VerticalSlideshow-slick', plugin_dir_url( __FILE__ ) . 'assets/public/js/slick.min.js', array('jquery'), '1.3', true );

		wp_enqueue_script( 'bwdvsix-VerticalSlideshow-main', plugin_dir_url( __FILE__ ) . 'assets/public/js/main.js', array('jquery'), '1.3', true );
		$all_css_file = array(
			'bwdvsix-VerticalSlideshow-plugin-slick' => array('bwdvsix-VerticalSlideshow_css_path_define'=>bwdvsix_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/slick.css'),
			'bwdvsix-VerticalSlideshow-plugin-main' => array('bwdvsix-VerticalSlideshow_css_path_define'=>bwdvsix_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/main.css'),
        );
        foreach($all_css_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdvsix-VerticalSlideshow_css_path_define'], null, '1.3', 'all');
        }

	}

	//admin-icon
	public function bwdvsix_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdvsix-VerticalSlideshow-admin-main' => array('bwdvsix_path_admin_define'=>bwdvsix_ASFSK_ASSETS_ADMIN_DIR_FILE . '/css/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdvsix_path_admin_define'], null, '1.3', 'all');
        }
	}

	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdvsix_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdvsix_all_assets_for_elementor_editor_admin']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdvsix_VerticalSlideshow_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdvsix_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdvsix_admin_editor_scripts' ] );

		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdvsix_VerticalSlideshow::instance();