<?php
/**
 * Plugin Name: Vertical Split Slideshow
 * Description: This is a fancy little slideshow where the image splits into two vertically. The left side moves down and the right side moves up.
 * Plugin URI:  https://bestwpdeveloper.com/vertical-split-slideshow
 * Version:     1.0
 * Author:      Best WP Developer
 * Author URI:  https://bestwpdeveloper.com/
 * Text Domain: bwdvsix-slideshow-vertical
 * Elementor tested up to: 3.0.0
 * Elementor Pro tested up to: 3.7.3
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once ( plugin_dir_path(__FILE__) ) . '/includes/bwdvsix-vertical-slideshow-activition.php';
final class bwdvsix_VerticalSlideshow{

	const VERSION = '1.3';

	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

	const MINIMUM_PHP_VERSION = '7.0';

	public function __construct() {
		// Load translation
		add_action( 'bwdvsix_init', array( $this, 'bwdvsix_loaded_textdomain' ) );
		// bwdvsix_init Plugin
		add_action( 'plugins_loaded', array( $this, 'bwdvsix_init' ) );
	}

	public function bwdvsix_loaded_textdomain() {
		load_plugin_textdomain( 'bwdvsix-slideshow-vertical', false, basename(dirname(__FILE__)).'/languages' );
	}

	public function bwdvsix_init() {
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', 'bwdvsix_VerticalSlideshow_addon_failed_load' );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdvsix_admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdvsix_admin_notice_minimum_php_version' ) );
			return;
		}

		// Once we get here, We have passed all validation checks so we can safely include our plugin
		require_once( 'bwdvsix-vertical-slideshow-boots.php' );
	}

	public function bwdvsix_admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdvsix-slideshow-vertical' ),
			'<strong>' . esc_html__( 'Vertical Split Slideshow', 'bwdvsix-slideshow-vertical' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'bwdvsix-slideshow-vertical' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdvsix-slideshow-vertical') . '</p></div>', $message );
	}

	public function bwdvsix_admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdvsix-slideshow-vertical' ),
			'<strong>' . esc_html__( 'Vertical Split Slideshow', 'bwdvsix-slideshow-vertical' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'bwdvsix-slideshow-vertical' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdvsix-slideshow-vertical') . '</p></div>', $message );
	}
}

// Instantiate Vertical Split Slideshow.
new bwdvsix_VerticalSlideshow();
remove_action( 'shutdown', 'wp_ob_end_flush_all', 1 );